@@ -33,7 +33,9 @@
 #include <string.h>
 #include <math.h>
 #include <ctype.h>
+#ifndef _WIN32
 #include <unistd.h> // for sleep
+#endif
 
 #ifdef NEWMIKMOD
 #include "mikmod.h"
@@ -134,9 +136,9 @@ typedef struct {
 
 #define C4SPD	8363
 #define C4mHz	523251
-#define C4	  523.251
-#define PI 	  3.141592653589793
-#define OMEGA	((2.0 * PI * C4)/(float)C4SPD)
+#define C4	  523.251f
+#define PI 	  3.141592653589793f
+#define OMEGA	((2.0f * PI * C4)/(float)C4SPD)
 
 /**************************************************************************
 **************************************************************************/
@@ -259,9 +261,9 @@ static float pat_sinus(int i)
 
 static float pat_square(int i)
 {
-	float res = 30.0 * sinf(OMEGA * (float)i);
-	if( res > 0.99 ) return 0.99;
-	if( res < -0.99 ) return -0.99;
+	float res = 30.0f * sinf(OMEGA * (float)i);
+	if( res > 0.99f ) return 0.99f;
+	if( res < -0.99f ) return -0.99f;
 	return res;
 }
 
@@ -276,8 +278,8 @@ static float pat_sawtooth(int i)
 		i = -2;
 	}
 	res = (float)i * res / PI;
-	if( res > 0.9 ) return 1.0 - res;
-	if( res < -0.9 ) return 1.0 + res;
+	if( res > 0.9f ) return 1.0f - res;
+	if( res < -0.9f ) return 1.0f + res;
 	return res;
 }
 
@@ -294,19 +296,23 @@ static PAT_SAMPLE_FUN pat_fun[] = { pat_sinus, pat_square, pat_sawtooth };
 
 #else
 
-#define MMSTREAM										FILE
-#define _mm_fopen(name,mode)				fopen(name,mode)
-#define _mm_fgets(f,buf,sz)					fgets(buf,sz,f)
+#if defined(WIN32) && defined(_mm_free)
+#undef _mm_free
+#endif
+
+#define MMSTREAM				FILE
+#define _mm_fopen(name,mode)			fopen(name,mode)
+#define _mm_fgets(f,buf,sz)			fgets(buf,sz,f)
 #define _mm_fseek(f,pos,whence)			fseek(f,pos,whence)
-#define _mm_ftell(f)								ftell(f)
+#define _mm_ftell(f)				ftell(f)
 #define _mm_read_UBYTES(buf,sz,f)		fread(buf,sz,1,f)
 #define _mm_read_SBYTES(buf,sz,f)		fread(buf,sz,1,f)
-#define _mm_feof(f)									feof(f)
-#define _mm_fclose(f)								fclose(f)
-#define DupStr(h,buf,sz)						strdup(buf)
-#define _mm_calloc(h,n,sz)					calloc(n,sz)
+#define _mm_feof(f)				feof(f)
+#define _mm_fclose(f)				fclose(f)
+#define DupStr(h,buf,sz)			strdup(buf)
+#define _mm_calloc(h,n,sz)			calloc(n,sz)
 #define _mm_recalloc(h,buf,sz,elsz)	realloc(buf,sz)
-#define _mm_free(h,p)								free(p)
+#define _mm_free(h,p)				free(p)
 
 typedef struct {
 	char *mm;
