@@ -59,6 +59,11 @@ typedef struct PTMSAMPLE
 #pragma pack()
 
 
+static uint32_t BS2WORD(uint16_t w[2]) {
+	uint32_t u32 = (w[1] << 16) + w[0];
+	return(bswapLE32(u32));
+}
+
 BOOL CSoundFile::ReadPTM(const BYTE *lpStream, DWORD dwMemLength)
 //---------------------------------------------------------------
 {
@@ -114,11 +119,10 @@ BOOL CSoundFile::ReadPTM(const BYTE *lpStream, DWORD dwMemLength)
 		if ((psmp->sampletype & 3) == 1)
 		{
 			UINT smpflg = RS_PCM8D;
-			pins->nLength = bswapLE32(*(LPDWORD)(psmp->length));
-			pins->nLoopStart = bswapLE32(*(LPDWORD)(psmp->loopbeg));
-			pins->nLoopEnd = bswapLE32(*(LPDWORD)(psmp->loopend));
-			DWORD samplepos = psmp->fileofs[1] << 16 +
-				psmp->fileofs[0];
+			pins->nLength = BS2WORD(psmp->length);
+			pins->nLoopStart = BS2WORD(psmp->loopbeg);
+			pins->nLoopEnd = BS2WORD(psmp->loopend);
+			DWORD samplepos = BS2WORD(psmp->fileofs);
 			if (psmp->sampletype & 4) pins->uFlags |= CHN_LOOP;
 			if (psmp->sampletype & 8) pins->uFlags |= CHN_PINGPONGLOOP;
 			if (psmp->sampletype & 16)
